spacepy.empiricals.getDststar — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »

# spacepy.empiricals.getDststar

`spacepy.empiricals.` `getDststar`(ticks, model='OBrien')

  Calculate the pressure-corrected Dst index, Dst*

  We need to add in the references to the models here!

  Parameters: | ticks : spacepy.time.Ticktock TickTock object of desired times (will be interpolated from hourly OMNI data) OR dictionary including ‘Pdyn’ and ‘Dst’ keys where data are lists or arrays and Dst is in [nT], and Pdyn is in [nPa]
  Returns: | out : float Dst* - the pressure corrected Dst index from OMNI [nT]

  Examples

  Coefficients are applied to the standard formulation e.g. Burton et al., 1975 of Dst* = Dst - b*sqrt(Pdyn) + c The default is the O’Brien and McPherron model (2002). Other options are Burton et al. (1975) and Borovsky and Denton (2010)

      >>> import spacepy.time as spt
      >>> import spacepy.omni as om
      >>> import spacepy.empiricals as emp
      >>> ticks = spt.tickrange('2000-10-16T00:00:00', '2000-10-31T12:00:00', 1/24.)
      >>> dststar = emp.getDststar(ticks)
      >>> dststar[0]
      -21.317220132108943

  User-determined coefficients can also be supplied as a two-element list or tuple of the form (b,c), e.g.

      >>> dststar = emp.getDststar(ticks, model=(2,11)) #b is extreme driving from O'Brien

  We have chosen the OBrien model as the default here as this was rigorously determined from a very long data set and is pertinent to most conditions. It is, however, the most conservative correction. Additionally, Siscoe, McPherron and Jordanova (2005) argue that the pressure contribution to Dst diminishes during magnetic storms.

  To show the relative differences, run the following example:

      >>> import matplotlib.pyplot as plt
      >>> params = [('Burton','k-'), ('OBrien','r-'), ('Borovsky','b-')]
      >>> for model, col in params:
              dststar = getDststar(ticks, model=model)
              plt.plot(ticks.UTC, dststar, col)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »